@@ -1,22 +1,23 @@
 #' Function for making an object of class \code{treedata}
-#' 
-#' This function generates an object of class \code{treedata} that ensures that the ordering of tip labels 
+#'
+#' This function generates an object of class \code{treedata} that ensures that the ordering of tip labels
 #' and data remain intact. The object can be manipulated using \code{dplyr} functions.
-#' 
+#'
 #' @param tree An object of class 'phylo'
 #' @param data A data frame or matrix
-#' @param name_column An optional argument that specifies the column of \code{data} that contains the 
-#' names to be matched to the tree. By default, it is set to "detect" which finds the column with the 
-#' most matches to the tree (including 
+#' @param name_column An optional argument that specifies the column of \code{data} that contains the
+#' names to be matched to the tree. By default, it is set to "detect" which finds the column with the
+#' most matches to the tree (including
 #' the rownames).
-#' @return An object of class "\code{treedata}". The tree is pruned of tips not represented in the data, 
-#' and the data is filtered for taxa not in the tree. The data is returned as a data frame tble that is 
-#' compatible with \code{dplyr} functions. 
+#' @param as.is Whether convert to factors. When FALSE (default), convert character vectors to factors. 
+#' @return An object of class "\code{treedata}". The tree is pruned of tips not represented in the data,
+#' and the data is filtered for taxa not in the tree. The data is returned as a data frame tble that is
+#' compatible with \code{dplyr} functions.
 #' @examples
 #' data(anolis)
 #' td <- make.treedata(anolis$phy, anolis$dat)
 #' @export
-make.treedata <- function(tree, data, name_column="detect") {
+make.treedata <- function(tree, data, name_column="detect", as.is=FALSE) {
   if(class(tree)!="phylo") stop("tree must be of class 'phylo'")
   if(is.vector(data)){
     data <- as.matrix(data)
@@ -42,8 +43,8 @@ make.treedata <- function(tree, data, name_column="detect") {
       name_column <- which(name_column==coln)[1]
     }
   }
-  dat <- tbl_df(as.data.frame(lapply(1:ncol(data), function(x) 
-    type.convert(apply(data[,x, drop=FALSE], 1, as.character)))))
+  dat <- as_tibble(as.data.frame(lapply(1:ncol(data), function(x)
+    type.convert(apply(data[,x, drop=FALSE], 1, as.character), as.is=as.is))))
   colnames(dat) <- coln
   if(name_column==0){
     clnm <- colnames(dat)
@@ -55,7 +56,7 @@ make.treedata <- function(tree, data, name_column="detect") {
     } else {
       clnm <- colnames(dat)[-which(colnames(dat)==name_column)]
     }
-    dat <- dat[, clnm, drop=FALSE]   
+    dat <- dat[, clnm, drop=FALSE]
     dat.label <- as.character(as.data.frame(data)[[name_column]])
   }
   data_not_tree <- setdiff(dat.label, tree$tip.label)
@@ -68,8 +69,8 @@ make.treedata <- function(tree, data, name_column="detect") {
     dat <- filter(dat, !duplicated(dat.label))
     dat.label <- dat.label[!duplicated(dat.label)]
   }
-  o <- match(dat.label, phy$tip.label)
-  dat <- arrange(dat, o)
+  ...my.order... <- match(dat.label, phy$tip.label)
+  dat <- arrange(dat, ...my.order...)
   td <- list(phy=phy, dat=dat)
   class(td) <- c("treedata", "list")
   attributes(td)$tip.label <- phy$tip.label
@@ -81,36 +82,45 @@ make.treedata <- function(tree, data, name_column="detect") {
 }
 
 #' Function for mutating an object of class \code{treedata}
-#' 
+#'
 #' This function can be used to add new variables to a treedata object; see \code{\link{mutate}}.
-#' 
-#' @aliases mutate.treedata mutate.grouped_treedata mutate_.grouped_treedata
+#'
+#' @aliases mutate.treedata mutate.grouped_treedata
 #' @param .data An object of class \code{treedata}
 #' @param ... Arguments to mutate the treedata object
-#' @param .dots Used to work around non-standard evaluation. See \code{vignette}("nse") for details.
-#' @return An object of class \code{treedata} with new data added. 
+#' @return An object of class \code{treedata} with new data added.
 #' @seealso \code{\link{mutate}}
 #' @examples
 #' data(anolis)
 #' td <- make.treedata(anolis$phy, anolis$dat)
 #' tdmutate <- mutate(td, lnSVL = log(SVL), badassery = awesomeness + hostility)
 #' @export
-mutate_.treedata <- function(.data, ..., .dots){
-  dots <- lazyeval::all_dots(.dots, ..., all_named=TRUE)
-  dat <- mutate_(.data$dat, .dots = dots)
-  #row.names(dat) <- attributes(.data)$tip.label
+mutate.treedata <- function(.data, ...){
+  dat <- mutate(.data$dat, ...)
   .data$dat <- dat
   return(.data)
 }
 
+
+#' @title mutate_.treedata
+#' @description Now defunct and replaced with mutate.treedata and mutate_.grouped_treedata.
+#'
+#' @name mutate_-defunct
+#' @seealso \code{\link{treeplyr-defunct}}
+#' @keywords internal
+#' @export
+mutate_.treedata <- function(.data, ...) {
+  .Defunct(msg = "'mutate_' has been removed from this package; you can use mutate instead")
+}
+
+
 #' Choose rows by their ordinal position in the tbl for an object of class \code{treedata}
-#' 
+#'
 #' This function can be used to drop tips from tree and data; see \code{\link{slice}}.
-#' 
+#'
 #' @param .data An object of class \code{treedata}
 #' @param ... Integer row values
-#' @param .dots Pair/values of expressions coercible to lazy objects.
-#' @return An object of class \code{treedata}. 
+#' @return An object of class \code{treedata}.
 #' @seealso \code{\link{slice}}
 #' @examples
 #' data(anolis)
@@ -118,71 +128,67 @@ mutate_.treedata <- function(.data, ..., .dots){
 #' tdslice <- slice(td, 1:5)
 #' tdslice
 #' @export
-slice_.treedata <- function(.data, ..., .dots){
-  dots <- lazyeval::all_dots(.dots, ..., all_named=TRUE)
+slice.treedata <- function(.data, ...){
   .data$dat$labelTEMP0123 <- .data$phy$tip.label
-  dat <- slice_(.data$dat, .dots = dots)
-  #row.names(dat) <- attributes(.data)$tip.label
+  dat <- slice(.data$dat, ...)
   .data <- make.treedata(.data$phy, dat)
   return(.data)
 }
 
 
+
+#' @title slice_.treedata
+#' @description Now defunct and replaced with slice.treedata
+#'
+#' @name slice_-defunct
+#' @seealso \code{\link{treeplyr-defunct}}
+#' @keywords internal
+#' @export
+slice_.treedata <- function(.data, ...) {
+  .Defunct(msg = "'slice_' has been removed from this package; you can use slice instead")
+}
+
 #' Function for selecting columns from an object of class \code{treedata}
-#' 
-#' This function can be used to select a subset of variables (columns) from a treedata object; 
+#'
+#' This function can be used to select a subset of variables (columns) from a treedata object;
 #' see \code{\link{select}}.
-#' 
-#' @aliases select_.grouped_treedata
+#'
+#' @aliases select.grouped_treedata
 #' @param .data An object of class \code{treedata}
 #' @param ... Additional arguments to select columns
-#' @param .dots Used to work around non-standard evaluation. See \code{vignette}("nse") for details.
-#' @return An object of class \code{treedata} with specified variables selected. 
+#' @return An object of class \code{treedata} with specified variables selected.
 #' @seealso \code{\link{select}}
 #' @examples
 #' data(anolis)
 #' td <- make.treedata(anolis$phy, anolis$dat)
 #' tdselect <- select(td, SVL, awesomeness)
 #' @export
-select_.treedata <- function(.data, ..., .dots = list()){
-   dat <- .data$dat
-  .data$dat <- select_(dat, ..., .dots=.dots)
-  return(.data)
-}
-
-#' Function for selecting columns from an object of class \code{treedata}
-#' 
-#' This function can be used to select a subset of variables (columns) from a treedata object; 
-#' see \code{\link{select}}.
-#' 
-#' @aliases select.grouped_treedata
-#' @param .data An object of class \code{treedata}
-#' @param ... Additional arguments to select columns
-#' @return An object of class \code{treedata} with specified variables selected. 
-#' @seealso \code{\link{select_}}
-#' @examples
-#' data(anolis)
-#' td <- make.treedata(anolis$phy, anolis$dat)
-#' tdselect <- select(td, SVL, awesomeness)
-#' @export
 select.treedata <- function(.data, ...){
-  #dots <- all_dots(.dots, ...)
-  #dat <- select(.data$dat, ...) #select_vars(names(.data$dat), !(!(!quos(...))))
-  #dat <- .data$dat[, vars, drop = FALSE]
-  #row.names(dat) <- attributes(.data)$tip.label
   .data$dat <- select(.data$dat, ...)
   return(.data)
 }
 
+
+#' @title select_.treedata
+#' @description Now defunct and replaced with select.treedata
+#'
+#' @name select_-defunct
+#' @seealso \code{\link{treeplyr-defunct}}
+#' @keywords internal
+#' @export
+select_.treedata <- function(.data, ...) {
+  .Defunct(msg = "'select_' has been removed from this package; you can use select instead")
+}
+
+
 #' Function for filtering rows from an object of class \code{treedata}
-#' 
-#' This function can be used to select a subset of species (rows) from a treedata object; 
+#'
+#' This function can be used to select a subset of species (rows) from a treedata object;
 #' see \code{\link{filter}}.
-#' 
-#' @aliases filter.treedata filter_.grouped_treedata filter.grouped_treedata
+#'
+#' @aliases filter.grouped_treedata
 #' @param .data An object of class \code{treedata}
-#' @param ... Additional arguments to filter by 
-#' @param .dots Used to work around non-standard evaluation. See \code{vignette}("nse") for details.
+#' @param ... Additional arguments to filter by
 #' @return An object of class \code{treedata} with the dataset filtered by the specified criteria.
 #' @seealso \code{\link{filter}}
 #' @examples
@@ -190,29 +196,39 @@ select.treedata <- function(.data, ...){
 #' td <- make.treedata(anolis$phy, anolis$dat, name_column=1)
 #' tdfilter <- filter(td, island=="Cuba", SVL > 3.5)
 #' @export
-filter_.treedata <- function(.data, ..., .dots){
-  dots <- lazyeval::all_dots(.dots, ...)
+filter.treedata <- function(.data, ...){
   tip.labels <- attributes(.data)$tip.label
   .data$dat <- mutate(.data$dat, tip.label=tip.labels)
-  dat <- filter_(.data$dat, .dots = dots)
+  dat <- filter(.data$dat, ...)
   .data$dat <- dat
   attributes(.data)$tip.label <- .data$dat$tip.label
   nc <- ncol(.data$dat)
   .data$dat <- select(.data$dat, 1:(nc-1))
   .data$phy <- drop.tip(.data$phy, .data$phy$tip.label[!(.data$phy$tip.label %in% attributes(.data)$tip.label)])
-  #attributes(.data$dat)$row.names <- .data$phy$tip.label
   return(.data)
 }
 
+
+#' @title filter_.treedata
+#' @description Now defunct and replaced with filter.treedata
+#'
+#' @name filter_-defunct
+#' @seealso \code{\link{treeplyr-defunct}}
+#' @keywords internal
+#' @export
+filter_.treedata <- function(.data, ...) {
+  .Defunct(msg = "'filter_' has been removed from this package; you can use select instead")
+}
+
 #' Function for summarizing an object of class \code{treedata}
-#' 
-#' This function can be used to summarize a treedata object. 
-#' 
+#'
+#' This function can be used to summarize a treedata object.
+#'
 #' @aliases summarize.treedata summarize.grouped_treedata summarise.grouped_treedata
 #' @param .data An object of class \code{treedata}
 #' @param ... Additional expressions by which to summarize data in the \code{treedata} object
 #' @details Summarizing \code{treedata} objects allows expressions using the objects \code{phy}. The \code{treedata}
-#' object can also be grouped, with summary statistics being applied to the pruned groups and phylogenies. 
+#' object can also be grouped, with summary statistics being applied to the pruned groups and phylogenies.
 #' @return An object of class \code{tbl_df} with the requested summary data.
 #' @seealso \code{\link{summarize}}, \code{\link{group_by}}
 #' @examples
@@ -220,7 +236,7 @@ filter_.treedata <- function(.data, ..., .dots){
 #' td <- make.treedata(anolis$phy, anolis$dat)
 #' summarize(td, ntips = length(phy$tip.label), meanSVL = mean(SVL), sdSVL = sd(SVL))
 #' tdGrouped <- group_by(td, ecomorph)
-#' summarize(tdGrouped, ntips = length(phy$tip.label), 
+#' summarize(tdGrouped, ntips = length(phy$tip.label),
 #'    totalBL = sum(phy$edge.length), meanSVL = mean(SVL), sdSVL = sd(SVL))
 #' @export
 summarise.treedata <- function(.data, ...){
@@ -236,40 +252,6 @@ summarise.treedata <- function(.data, ...){
 }
 
 
-# Function for summarizing an object of class \code{treedata}
-# 
-# This function can be used to summarize a treedata object. 
-# 
-# @aliases summarise_.treedata summarize_.grouped_treedata summarise_.grouped_treedata
-# @param .data An object of class \code{treedata}
-# @param ... Additional expressions by which to summarize data in the \code{treedata} object
-# @param .dots Used to work around non-standard evaluation. See \code{vignette}("nse") for details.
-# @details Summarizing \code{treedata} objects allows expressions using the objects \code{phy}. The \code{treedata}
-# object can also be grouped, with summary statistics being applied to the pruned groups and phylogenies. 
-# @return An object of class \code{tbl_df} with the requested summary data.
-# @seealso \code{\link{summarize}}, \code{\link{group_by}}
-# @examples
-# data(anolis)
-# td <- make.treedata(anolis$phy, anolis$dat)
-# summarize(td, ntips = length(phy$tip.label), meanSVL = mean(SVL), sdSVL = sd(SVL))
-# tdGrouped <- group_by(td, ecomorph)
-# summarize(tdGrouped, ntips = length(phy$tip.label), 
-#    totalBL = sum(phy$edge.length), meanSVL = mean(SVL), sdSVL = sd(SVL))
-# @export
-#summarise_.treedata <- function(.data, ..., .dots=list()){
-  #if(is.null(list(substitute(...))[[1]])) stop("No expression provided to summarize data")
-#  dots <- lazyeval::all_dots(.dots, ..., all_named = TRUE)
-#  env <- new.env(parent = parent.frame(), size = 1L)
-#  env$phy <- .data$phy
-#  env$dat <- as.data.frame(.data$dat)
-#  env$tip.label <- .data$phy$tip.label
-#  #rownames(env$dat) <- env$phy$tip.label
-#  for(i in 1:length(dots)){
-#    dots[[i]]$env <- env
-#  }
-#  res <- summarise_(.data$dat, .dots = dots)
-#  return(res)
-#}
 
 #' @rdname summarise.treedata
 #' @export
@@ -303,33 +285,45 @@ summarise.grouped_treedata <- function(.data, ...){
 }
 
 #' Function for grouping an object of class \code{treedata}
-#' 
-#' This function can be used to group a treedata object by some factor. 
-#' 
+#'
+#' This function can be used to group a treedata object by some factor.
+#'
 #' @aliases group_by.treedata
 #' @param .data An object of class \code{treedata}
 #' @param ... The name of the grouping factor.
-#' @param add By default, when add = FALSE, group_by will override existing groups. 
-#' To instead add to the existing groups, use add = TRUE
+#' @param .add By default, when .add = FALSE, group_by will override existing groups.
+#' To instead add to the existing groups, use .add = TRUE
 #' @param x An object of class \code{treedata}
 #' @details Groups the data frame and phylogeny by one of the factors in the data table.
-#' @return An object of class \code{grouped_treedata}. 
+#' @return An object of class \code{grouped_treedata}.
 #' @seealso \code{\link{summarize}}
 #' @examples
 #' data(anolis)
 #' td <- make.treedata(anolis$phy, anolis$dat)
 #' tdGrouped <- group_by(td, ecomorph)
-#' summarize(tdGrouped, ntips = length(phy$tip.label), 
+#' summarize(tdGrouped, ntips = length(phy$tip.label),
 #'    totalBL = sum(phy$edge.length), meanSVL = mean(SVL), sdSVL = sd(SVL))
 #' @export
-group_by_.treedata <- function(.data, ..., add=FALSE){
-  groups <- group_by_prepare(.data$dat, ..., add = add)
-  dat <- grouped_df(groups$data, groups$groups)
+group_by.treedata <- function(.data, ..., .add=FALSE){
+  groups <- group_by_prepare(.data$dat, ..., .add = .add)
+  dat <- grouped_df(groups$data, groups$group_names)
   .data$dat <- dat
   class(.data) <- c("grouped_treedata", "treedata", "list")
   return(.data)
 }
 
+
+#' @title group_by_.treedata
+#' @description Now defunct and replaced with group_by.treedata.
+#'
+#' @name group_by_-defunct
+#' @seealso \code{\link{treeplyr-defunct}}
+#' @keywords internal
+#' @export
+group_by_.treedata <- function(.data, ..., add = FALSE) {
+    .Defunct(msg = "'group_by_' has been removed from this package; you can use group_by instead")
+}
+
 #' @rdname reorder.treedata
 #' @export
 reorder <- function(tdObject, ...){
@@ -337,17 +331,17 @@ reorder <- function(tdObject, ...){
 }
 
 #' Reorder a \code{treedata} object
-#' 
+#'
 #' Reorders a \code{treedata} object. Both the tips and the data are automatically reordered to match.
-#' 
+#'
 #' @param tdObject An object of class \code{treedata}
 #' @param order Method for reordering
 #' @param index.only Whether a index is returned rather than the reordered treedata object
 #' @param ... Additional arguments to reorder.phylo
 #' @return An object of class \code{treedata}
-#' 
+#'
 #' @seealso \code{\link{reorder.phylo}}
-#' 
+#'
 #' @examples
 #' data(anolis)
 #' td <- make.treedata(anolis$phy, anolis$dat)
@@ -359,7 +353,7 @@ reorder.treedata <- function(tdObject, order="postorder", index.only=FALSE, ...)
   index <- match(tdObject$phy$tip.label, phy$tip.label)
   tdObject$dat <- tdObject$dat[index,]
   attributes(tdObject$dat) <-dat.attr
-  #attributes(tdObject$dat)$row.names 
+  #attributes(tdObject$dat)$row.names
   attributes(tdObject)$tip.label <- phy$tip.label
   tdObject$phy <- phy
   if(index.only){
@@ -376,26 +370,26 @@ treeply <- function(tdObject, ...){
 }
 
 #' Run a function on the phylogeny of a \code{treedata} object
-#' 
-#' Applies a function to the phylogeny in a \code{treedata} object. If the order of 
-#' tips are changed, or if tips are dropped, then the data are automatically reordered 
+#'
+#' Applies a function to the phylogeny in a \code{treedata} object. If the order of
+#' tips are changed, or if tips are dropped, then the data are automatically reordered
 #' to match the tree.
-#' 
+#'
 #' @param tdObject An object of class \code{treedata}
 #' @param FUN A function that operates on an object of class 'phylo'
 #' @param ... Additional arguments
 
 #' @return An object of class \code{treedata}
-#' 
+#'
 #' @examples
 #' data(anolis)
 #' td <- make.treedata(anolis$phy, anolis$dat)
 #' td2 <- treeply(td, drop.tip, 1:50)
-#'   
+#'
 #' par(mfrow=c(1,2))
 #' plot(td$phy)
 #' plot(td2$phy)
-#' 
+#'
 #' @export
 treeply.treedata <- function(tdObject, FUN, ...){
   if(!class(tdObject)[1]=="treedata") stop("Object is not of class 'treedata'")
@@ -409,20 +403,20 @@ treeply.treedata <- function(tdObject, FUN, ...){
   } else {
     warning("Function output was not of class 'phylo', returning output only")
     return(out_FUN)
-  } 
+  }
 }
 
-#' Apply a function over all treedata object columns and return a list of results, analogously to the 
+#' Apply a function over all treedata object columns and return a list of results, analogously to the
 #' normal apply function
-#' 
+#'
 #' @param tdObject A treedata object
 #' @param MARGIN the margin over which the data is applied (e.g. 1 = rows, 2 = columns)
 #' @param FUN A function to apply over the data frame
 #' @param ... Additional parameters passed on to FUN
-#' 
-#' @details Note that if the parameter \code{phy} is specified in the additional parameters (i.e. '...'), 
-#' then it will be substituted with the \code{treedata} object \code{$phy}. 
-#' 
+#'
+#' @details Note that if the parameter \code{phy} is specified in the additional parameters (i.e. '...'),
+#' then it will be substituted with the \code{treedata} object \code{$phy}.
+#'
 #' @examples
 #' data(anolis)
 #' td <- make.treedata(anolis$phy, anolis$dat)
@@ -449,15 +443,15 @@ treedply <- function(tdObject, ...){
 }
 
 #' Run a function on a \code{treedata} object
-#' 
+#'
 #' @param tdObject A treedata object
 #' @param ... A function call.
-#' 
-#' @details This function allows arbitrary R functions that use trees and data to be run on 
-#' \code{treedata} objects. 
-#' 
+#'
+#' @details This function allows arbitrary R functions that use trees and data to be run on
+#' \code{treedata} objects.
+#'
 #' @return Function output
-#' 
+#'
 #' @examples
 #' data(anolis)
 #' td <- make.treedata(anolis$phy, anolis$dat)
@@ -486,7 +480,7 @@ treedply.treedata <- function(tdObject, ...){
 #'
 #' @param td A treedata object
 #' @param ... The name of the column to select
-#' 
+#'
 #' @return A named vector
 #' @export
 getVector <- function(td, ...){
@@ -506,14 +500,14 @@ getVector <- function(td, ...){
 print.treedata <- function(x, ...){
   cat("$phy \n")
   print(x$phy)
-  
+
   cat("\n$dat \n")
   print(x$dat)
 }
 
 #' @export
 summary.treedata <- function(object, ...){
- 
+
   cat('A treeplyr treedata object', "\n")
   cat(paste('The dataset contains ', ncol(object$dat), ' traits'), "\n")
   types <- setNames(suppressWarnings(detectAllCharacters(as.matrix(object$dat))), colnames(object$dat))
@@ -523,7 +517,7 @@ summary.treedata <- function(object, ...){
   cat(paste("These taxa were dropped from the tree:", paste(attributes(object)$dropped$dropped_from_tree, collapse=", "), "\n"))
   cat(paste("These taxa were dropped from the data:", paste(attributes(object)$dropped$dropped_from_data, collapse=", "), "\n"))
 
-  
+
   cat("$phy \n")
   print(object$phy)
   cat("\n$dat \n")
@@ -532,16 +526,16 @@ summary.treedata <- function(object, ...){
 
 
 
-#' Function for checking whether a treedata object contains only numeric columns and for forcing 
+#' Function for checking whether a treedata object contains only numeric columns and for forcing
 #' data columns into numeric format
-#' 
-#' This function can be used to check if a treedata object contains numeric columns and, if 
+#'
+#' This function can be used to check if a treedata object contains numeric columns and, if
 #' desired, drop all non-numeric columns.
-#' 
+#'
 #' @param tdObject A \code{treedata} object
-#' @param return.numeric If TRUE, then a treedata object with all numeric columns will be returned; 
+#' @param return.numeric If TRUE, then a treedata object with all numeric columns will be returned;
 #' non-numeric columns will be removed.
-#' @return If return.numeric, then an object of class "\code{treedata}" with only numeric columns. 
+#' @return If return.numeric, then an object of class "\code{treedata}" with only numeric columns.
 #' @examples
 #' data(anolis)
 #' td <- make.treedata(anolis$phy, anolis$dat)
@@ -551,7 +545,7 @@ forceNumeric <- function(tdObject, return.numeric=TRUE) {
   valid <- which(sapply(tdObject$dat, is.numeric))
   if(length(valid) < ncol(tdObject$dat)){
     if(length(valid)==0){
-      warning("Dataset does not contain any numeric data") 
+      warning("Dataset does not contain any numeric data")
       tdObject <- select(tdObject)
     } else {
       not.valid <- colnames(tdObject$dat)[which(!sapply(tdObject$dat, is.numeric))]
@@ -566,18 +560,18 @@ forceNumeric <- function(tdObject, return.numeric=TRUE) {
   }
 }
 
-#' Function for checking whether a treedata object contains only factors and for forcing 
+#' Function for checking whether a treedata object contains only factors and for forcing
 #' data columns into factor format
-#' 
-#' This function can be used to check if a treedata object contains factors and, if desired, 
+#'
+#' This function can be used to check if a treedata object contains factors and, if desired,
 #' convert all columns automatically to factors.
-#' 
+#'
 #' @param tdObject A \code{treedata} object
-#' @param return.factor If TRUE, then a treedata object with all factors will be returned; 
-#' columns will be forced into factors using \code{factor} and any with no repeated elements 
+#' @param return.factor If TRUE, then a treedata object with all factors will be returned;
+#' columns will be forced into factors using \code{factor} and any with no repeated elements
 #' will be removed.
-#' @return If return.factor, then an object of class "\code{treedata}" with all columns as 
-#' factors. 
+#' @return If return.factor, then an object of class "\code{treedata}" with all columns as
+#' factors.
 #' @examples
 #' data(anolis)
 #' td <- make.treedata(anolis$phy, anolis$dat)
@@ -604,7 +598,7 @@ forceFactor <- function(tdObject, return.factor=TRUE) {
     }
 
     if(length(valid)==0){
-      warning("Data does not contain any discrete data") 
+      warning("Data does not contain any discrete data")
       tdObject <- select(tdObject)
     } else {
       tdObject$dat <- select(tdObject$dat, valid)
@@ -617,23 +611,32 @@ forceFactor <- function(tdObject, return.factor=TRUE) {
   }
 }
 
-#' @rdname mutate_.treedata
+#' @rdname mutate.treedata
 #' @export
-mutate_.grouped_treedata <- function(.data, ..., .dots){
-  dots <- all_dots(.dots, ..., all_named=TRUE)
-  dat <- mutate_(.data$dat, .dots = dots)
-  #row.names(dat) <- .data$phy$tip.label
+mutate.grouped_treedata <- function(.data, ...){
+  dat <- mutate(.data$dat, ...)
   .data$dat <- dat
   return(.data)
 }
 
-#' @rdname filter_.treedata
+
+#' @title mutate_.grouped_treedata
+#' @description Now defunct and replaced with mutate.groupedtreedata.
+#'
+#' @name mutate_-defunct
+#' @seealso \code{\link{treeplyr-defunct}}
+#' @keywords internal
 #' @export
-filter_.grouped_treedata <- function(.data, ..., .dots){
-  dots <- all_dots(.dots, ...)
+mutate_.grouped_treedata <- function(.data, ..., add = FALSE) {
+  .Defunct(msg = "'mutate_' has been removed from this package; you can use group_by instead")
+}
+
+#' @rdname filter.treedata
+#' @export
+filter.grouped_treedata <- function(.data, ...){
   cl <- class(.data$dat)
   .data$dat$tip.label <- .data$phy$tip.label
-  dat <- filter_(.data$dat, .dots = dots)
+  dat <- filter_(.data$dat, ...)
   .data$dat <- dat
   attributes(.data)$tip.label <- .data$dat$tip.label
   .data$dat <- select(.data$dat, 1:(ncol(.data$dat)-1))
@@ -642,28 +645,39 @@ filter_.grouped_treedata <- function(.data, ..., .dots){
   return(.data)
 }
 
+#' @title filter_.grouped_treedata
+#' @description Now defunct and replaced with filter.groupedtreedata.
+#'
+#' @name filter_-defunct
+#' @seealso \code{\link{treeplyr-defunct}}
+#' @keywords internal
+#' @export
+filter_.grouped_treedata <- function(.data, ...) {
+  .Defunct(msg = "'filter_' has been removed from this package; you can use filter instead")
+}
+
 #' Add regimes to a treedata object
-#' 
+#'
 #' This function paints clades on the phylogeny and adds a data column that specifies to which clade each species
 #' belongs
 #' @param tdObject A \code{treedata} object
 #' @param nclades The number of clades that will be specified if used interactively
 #' @param name The name of the resulting data column
 #' @param interactive If \code{TRUE}, then a plot will appear that will allow the user to click on \code{nclades}
-#' branches. The selections will then be coverted into the data table. 
-#' @param type Either "nodes" or "branches" specifying if the ids provided specify the branch id (assuming a 
+#' branches. The selections will then be coverted into the data table.
+#' @param type Either "nodes" or "branches" specifying if the ids provided specify the branch id (assuming a
 #' post-ordered tree) or the node number. Ignored if \code{interactive = TRUE}.
 #' @param ids A vector of node numbers of branch numbers that specify clades. Ignored if \code{interactive=TRUE}.
-#' @param plot If \code{TRUE} and \code{interactive = FALSE} then a simmap plot is produced. 
-#' @examples 
+#' @param plot If \code{TRUE} and \code{interactive = FALSE} then a simmap plot is produced.
+#' @examples
 #' data(anolis)
 #' td <- make.treedata(anolis$phy, anolis$dat)
 #' td <- reorder(td, "postorder")
-#' td.painted <- paint_clades(td, interactive=FALSE, type="nodes", 
+#' td.painted <- paint_clades(td, interactive=FALSE, type="nodes",
 #'                                    ids=c(184, 160, 135, 122), plot=TRUE)
 #' td.painted <- group_by(td.painted, clades)
-#' summarise(td.painted, 
-#'              psig1 = phytools::phylosig(setNames(SVL, phy$tip.label), tree=phy), 
+#' summarise(td.painted,
+#'              psig1 = phytools::phylosig(setNames(SVL, phy$tip.label), tree=phy),
 #'                    meanSVL = mean(SVL))
 #' @export
 paint_clades <- function(tdObject, nclades=1, name="clades", interactive=TRUE, type="nodes", ids=NULL, plot=TRUE){
@@ -671,19 +685,19 @@ paint_clades <- function(tdObject, nclades=1, name="clades", interactive=TRUE, t
   if(interactive){
     regimes <- .identifyBranches(tdObject$phy, nclades)
     cat("branches ", paste(regimes$sb, collapse=", "), "selected\n")
-    } else 
+    } else
     {
     if(type == "nodes"){
       if(any(!ids %in% (length(tdObject$phy$tip.label)+1):max(tdObject$phy$edge))) stop("Please specify valid internal node ids")
       nclades = length(ids)
       regimes <- list(sb = match(ids, tdObject$phy$edge[,2]), loc = rep(0, nclades))
 
-    } 
+    }
     if(type == "branches"){
       if(any(!ids %in% (1:nrow(tdObject$phy$edge)))) stop("Please specify valid branch ids")
       nclades = length(ids)
       regimes <- list(sb = ids, loc = rep(0, nclades))
-    }      
+    }
       if(plot){
         sb <- regimes$sb
         n <- nclades
@@ -695,7 +709,7 @@ paint_clades <- function(tdObject, nclades=1, name="clades", interactive=TRUE, t
         L <- get("last_plot.phylo", envir = .PlotPhyloEnv)
         legend(min(L$xx), max(L$yy), legend=names(cols), lwd=3, col=cols)
       }
-      
+
     }
   regimes$t2 <- 2:(length(regimes$sb)+1)
   regimes$k <- nclades
@@ -705,20 +719,20 @@ paint_clades <- function(tdObject, nclades=1, name="clades", interactive=TRUE, t
   return(tdObject)
 }
 
-#' @rdname group_by_.treedata
+#' @rdname group_by.treedata
 #' @export
 ungroup.grouped_treedata <- function(x, ...){
   x$dat <- ungroup(x$dat, ...)
   return(x)
 }
 
-#' @export 
+#' @export
 '[[.treedata' <- function(x, ..., exact=TRUE){
   y <- x$dat
   res <- '[[.data.frame'(y, ..., exact=exact)
   if(length(res) != nrow(y)){
     stop("Use '[' for selecting multiple columns")
-  } 
+  }
   return(setNames(res, x$phy$tip.label))
 }
 
@@ -736,7 +750,7 @@ ungroup.grouped_treedata <- function(x, ...){
       }
     }
   }
-  if (drop) 
+  if (drop)
     warning("drop ignored", call. = FALSE)
   nr <- nrow(y)
   if (nargs() <= 2L) {
@@ -778,7 +792,7 @@ ungroup.grouped_treedata <- function(x, ...){
 
 #' as_data_frame.data.frame function from the tibble package
 #' @keywords internal
-.as_data_frame.data.frame <- function (x, ...) 
+.as_data_frame.data.frame <- function (x, ...)
 {
   class(x) <- c("tbl_df", "tbl", "data.frame")
   x
